============
Contributing
============

Thank you for interested to ``sphinx-revealjs``.

.. todo:: Add USING, QUESTION and DOCUMENTATION

Contribute code
===============

Local development environment
-----------------------------

This is base spec for development by author( ``attakei`` ) on 2022/08/27.

* Arch Linux
* Python 3.9 (using uv)
* Installed `pre-commit <https://pre-commit.com/>`_ globally

Setting up repo
---------------

After you clone forked Git repository, Setup workspace.
Please see :doc:`./local-workspace`.
